#!/bin/ksh
#
#* **************************************************************************
#* **************************************************************************
#* * (C) COPYRIGHT HEWLETT-PACKARD COMPANY 1994-1996. ALL RIGHTS RESERVED.  *
#* * No part of this program may be photocopied, reproduced or translated   *
#* * to another program language without the prior written consent of the   *
#* * Hewlett-Packard Company.                                               *
#* **************************************************************************
#* **************************************************************************
#
# dl.serial - download new firmware via RS232
#	Usage:	dl.serial [[port_name] ram]
# 	Aux programs needed: split_dl, ldhpib.700
#	Data files needed: falcon.trg

# Variable initialization
PATH=.:$PATH
DEV=${1:-/dev/tty00}
FLASH=${2:-T}
FLASH=${FLASH#ram}
XLATE=falcon.out
RMXLATE=""
HON=`tput smso`
HOFF=`tput rmso`

# Parameter checking
if [ ! -c "$DEV" ] || [ ! -w "$DEV" ]
then
    echo "$0: Cannot access device file $DEV"
    exit 1
fi

# Initial messages
echo "NOTE: when asked to press [Return], this means press the HP-UX
system keyboard [Return] key - NOT the similarly labeled key on the
instrument!\n"

# Initial setup
echo "${HON}Turn off the instrument, then press [Return]:${HOFF} \c"
reply=`line`
echo "\n${HON}Connect the serial cable from the instrument to $DEV,"
echo "${HON}then press [Return]:${HOFF} \c"
reply=`line`

# Establish serial port
sleep 999999999 < $DEV &
pid=$!
trap "echo trap exit;kill $pid;/bin/rm -f \$RMXLATE;exit 1" INT QUIT
stty 19200 \
	min 1 eof '^A' start '^Q' stop '^S' \
	-parity clocal -inpck -istrip -ixon -ixoff -isig -icanon iexten \
	-echo -echoe -echok \
	< $DEV &

# Prepare the download image
if [ ! -r "$XLATE" ]
then
	RMXLATE="$XLATE"
	touch $XLATE
	chmod 600 $XLATE
	ldhpib.700 -b -h -f falcon.trg -o $XLATE
fi

# Warn the user.
echo "${HON}You are about to be prompted to turn on the instrument.\c"
echo "(Do NOT do it yet.)${HOFF}"
echo "${HON}Once the prompt is given, you must respond within 5 seconds${HOFF}"
echo "${HON}to avoid a synchronization problem.${HOFF}"
echo "${HON}The download will start automatically.${HOFF}"
echo "${HON}DO NOT INTERRUPT OR CYCLE POWER!!!${HOFF}";
echo "${HON}Please wait...${HOFF}"
sleep 15

if [ -n "$FLASH" ]
then
    split_dl -v -i $XLATE -d $DEV
else
    split_dl -v -i /dev/null -d $DEV -f "hm RS232BINARY"
    echo "Firmware now downloading..."
    cat $XLATE >> $DEV
    /bin/echo "EF" >> $DEV
fi

# Clean up and exit
kill $pid
/bin/rm -f $RMXLATE
exit 0
